package de.stefanfrings.demo;

import java.io.IOException;
import java.util.List;
import javax.enterprise.inject.spi.CDI;
import javax.inject.Inject;
import org.apache.deltaspike.testcontrol.api.junit.CdiTestRunner;
import org.apache.deltaspike.testcontrol.api.mock.DynamicMockManager;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

@RunWith(CdiTestRunner.class)
public class BusinessLogicTest {
       
    @Inject
    private BusinessLogic businessLogic;
    
    @Test
    public void testDbAccess() {
        List<Friend> list = businessLogic.listAllFriends();
        assertEquals(list.size(),4);
    }    
    
    @Before
    public void setup() {
        HttpInterface i=CDI.current().select(HttpInterface.class).get();
        CDI.current().destroy(i);
    }
    
    @Test
    public void testHttpCommunication() {       
        String content=businessLogic.getStefansHomepage();
        assertTrue(content.contains("Stefan"));
    }
    
    @Inject
    private DynamicMockManager mockManager;
        
    @Test
    public void testHttpCommunicationWithMock() throws Exception {
        
        mockManager.addMock(new HttpInterface() {
            @Override
            public String readFromUrl(String url) throws IOException {
                throw new IOException("Server returned HTTP response code: 500 for URL: "+url);
            }
        });

        String content=businessLogic.getStefansHomepage();
        assertTrue(content.contains("error"));
        assertTrue(content.contains("HTTP response code: 500"));
    } 
    
    @Test
    public void testHttpCommunicationWithMock2() throws Exception {
        
        mockManager.addMock(new HttpInterface() {
            @Override
            public String readFromUrl(String url) throws IOException {
                return "Sorry, this page is under construction";
            }
        });
        
        String content=businessLogic.getStefansHomepage();
        assertTrue(content.contains("under construction"));
    } 
    
}
